@@ -9,7 +9,7 @@ use base 'Log::Dispatch::Email';
 
 use Email::Mailer 1.09;
 
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 sub _params {
     my %params = @_;
@@ -69,7 +69,7 @@ Log::Dispatch::Email::Mailer - Log::Dispatch::Email subclass that sends mail usi
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Log-Dispatch-Email-Mailer.svg)](https://travis-ci.org/gryphonshafer/Log-Dispatch-Email-Mailer)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Log-Dispatch-Email-Mailer/badge.png)](https://coveralls.io/r/gryphonshafer/Log-Dispatch-Email-Mailer)
@@ -292,18 +292,10 @@ L<GitHub|https://github.com/gryphonshafer/Log-Dispatch-Email-Mailer>
 
 =item *
 
-L<CPAN|http://search.cpan.org/dist/Log-Dispatch-Email-Mailer>
-
-=item *
-
 L<MetaCPAN|https://metacpan.org/pod/Log::Dispatch::Email::Mailer>
 
 =item *
 
-L<AnnoCPAN|http://annocpan.org/dist/Log-Dispatch-Email-Mailer>
-
-=item *
-
 L<Travis CI|https://travis-ci.org/gryphonshafer/Log-Dispatch-Email-Mailer>
 
 =item *
@@ -326,7 +318,7 @@ Gryphon Shafer <gryphon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Gryphon Shafer.
+This software is copyright (c) 2020 by Gryphon Shafer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
